@@ -1,6 +1,3 @@
-use strict;
-use warnings;
-
 package Mojolicious::Plugin::Cron;
 use Mojo::Base 'Mojolicious::Plugin';
 use File::Spec;
@@ -11,7 +8,7 @@ use Algorithm::Cron;
 
 use Carp 'croak';
 
-our $VERSION = "0.022";
+our $VERSION = "0.023";
 use constant CRON_DIR => 'mojo_cron_dir';
 my $crondir;
 
@@ -164,7 +161,7 @@ Each crontab line consists of a hash with the following keys:
  
 =item base => STRING
  
-Gives the time base used for scheduling. Either C<utc> or C<local>.
+Gives the time base used for scheduling. Either C<utc> or C<local> (default C<local>.
  
 =item crontab => STRING
  
